@@ -2,7 +2,7 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 8.1.0
+# Version 9.5.0
 # Copyright (C) 2019-2023 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -14,6 +14,7 @@ __metaclass__ = type
 
 import pytest
 import json
+from unittest.mock import MagicMock
 from ansible_collections.dellemc.openmanage.plugins.modules import idrac_redfish_storage_controller
 from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import FakeAnsibleModule
 from ansible.module_utils.six.moves.urllib.error import HTTPError, URLError
@@ -22,6 +23,10 @@ from io import StringIO
 from ansible.module_utils._text import to_text
 
 MODULE_PATH = 'ansible_collections.dellemc.openmanage.plugins.modules.'
+HTTPS_ADDRESS = 'https://testhost.com'
+HTTP_ERROR_MSG = 'http error message'
+RAID_INTEGRATED_1_1 = "RAID.Integrated.1-1"
+ODATA_ID = "@odata.id"
 
 
 @pytest.fixture
@@ -37,35 +42,35 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
     module = idrac_redfish_storage_controller
 
     def test_check_id_exists(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password"}
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password"}
         uri = "/redfish/v1/Dell/Systems/{system_id}/Storage/DellController/{controller_id}"
         f_module = self.get_module_mock(params=param)
         redfish_response_mock.success = True
         redfish_response_mock.status_code = 200
         result = self.module.check_id_exists(f_module, redfish_str_controller_conn, "controller_id",
-                                             "RAID.Integrated.1-1", uri)
+                                             RAID_INTEGRATED_1_1, uri)
         assert result is None
 
         redfish_response_mock.success = False
         redfish_response_mock.status_code = 400
         with pytest.raises(Exception) as ex:
             self.module.check_id_exists(f_module, redfish_str_controller_conn, "controller_id",
-                                        "RAID.Integrated.1-1", uri)
+                                        RAID_INTEGRATED_1_1, uri)
         assert ex.value.args[0] == "controller_id with id 'RAID.Integrated.1-1' not found in system"
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         with pytest.raises(Exception) as ex:
             self.module.check_id_exists(f_module, redfish_str_controller_conn, "controller_id",
-                                        "RAID.Integrated.1-1", uri)
+                                        RAID_INTEGRATED_1_1, uri)
         assert ex.value.args[0] == "controller_id with id 'RAID.Integrated.1-1' not found in system"
 
     def test_validate_inputs(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "ReKey", "mode": "LKM"}
         f_module = self.get_module_mock(params=param)
         with pytest.raises(Exception) as ex:
@@ -132,7 +137,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert result is None
 
     def test_target_identify_pattern(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "BlinkTarget", "target": "Disk.Bay.1:Enclosure.Internal.0-0:RAID.Mezzanine.1C-1",
                  "volume_id": "Disk.Virtual.0:RAID.Mezzanine.1C-1"}
         f_module = self.get_module_mock(params=param)
@@ -162,7 +167,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert result.status_code == 200
 
     def test_ctrl_reset_config(self, redfish_str_controller_conn, redfish_response_mock, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "controller_id": "RAID.Mezzanine.1C-1", "command": "ResetConfig"}
         f_module = self.get_module_mock(params=param)
         mocker.patch(MODULE_PATH + "idrac_redfish_storage_controller.check_id_exists", return_value=None)
@@ -180,7 +185,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "No changes found to be applied."
 
     def test_hot_spare_config(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "AssignSpare", "target": ["Disk.Bay.1:Enclosure.Internal.0-2:RAID.Integrated.1-1"]}
         f_module = self.get_module_mock(params=param)
         redfish_response_mock.json_data = {"HotspareType": "None"}
@@ -205,8 +210,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         with pytest.raises(Exception) as ex:
@@ -214,8 +219,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "Unable to locate the physical disk with the ID: Disk.Bay.1:Enclosure.Internal.0-2:RAID.Integrated.1-1"
 
     def test_ctrl_key(self, redfish_str_controller_conn, redfish_response_mock, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "command": "SetControllerKey", "controller_id": "RAID.Integrated.1-1", "mode": "LKM"}
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "command": "SetControllerKey", "controller_id": RAID_INTEGRATED_1_1, "mode": "LKM"}
         mocker.patch(MODULE_PATH + "idrac_redfish_storage_controller.check_id_exists", return_value=None)
         f_module = self.get_module_mock(params=param)
         redfish_response_mock.json_data = {"SecurityStatus": "EncryptionNotCapable", "KeyID": None}
@@ -296,7 +301,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert result[2] == "JID_XXXXXXXXXXXXX"
 
     def test_convert_raid_status(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "ConvertToRAID", "target": ["Disk.Bay.0:Enclosure.Internal.0-1:RAID.Slot.1-1",
                                                         "Disk.Bay.1:Enclosure.Internal.0-1:RAID.Slot.1-1"]}
         f_module = self.get_module_mock(params=param)
@@ -318,8 +323,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         with pytest.raises(Exception) as ex:
@@ -327,7 +332,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "Unable to locate the physical disk with the ID: Disk.Bay.0:Enclosure.Internal.0-1:RAID.Slot.1-1"
 
     def test_change_pd_status(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "ChangePDStateToOnline",
                  "target": ["Disk.Bay.0:Enclosure.Internal.0-1:RAID.Slot.1-1",
                             "Disk.Bay.1:Enclosure.Internal.0-1:RAID.Slot.1-1"]}
@@ -350,8 +355,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         with pytest.raises(Exception) as ex:
@@ -359,7 +364,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "Unable to locate the physical disk with the ID: Disk.Bay.0:Enclosure.Internal.0-1:RAID.Slot.1-1"
 
     def test_lock_virtual_disk(self, redfish_str_controller_conn, redfish_response_mock, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "LockVirtualDisk",
                  "volume_id": ["Disk.Virtual.0:RAID.SL.3-1"]
                  }
@@ -385,10 +390,10 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
                                            "Links": {
                                                "Drives": [
                                                    {
-                                                       "@odata.id": "/redfish/v1/Systems/System.Embedded.1/"
+                                                       ODATA_ID: "/redfish/v1/Systems/System.Embedded.1/"
                                                    },
                                                    {
-                                                       "@odata.id": "/redfish/v1/Systems/System.Embedded.1/"
+                                                       ODATA_ID: "/redfish/v1/Systems/System.Embedded.1/"
                                                    }],
                                                "Drives@odata.count": 2}}
         with pytest.raises(Exception) as ex:
@@ -397,8 +402,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         with pytest.raises(Exception) as ex:
@@ -406,7 +411,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "Unable to locate the physical disk with the ID: RAID.SL.3-1"
 
     def test_online_capacity_expansion_raid_type_error(self, redfish_str_controller_conn, redfish_response_mock, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "OnlineCapacityExpansion",
                  "volume_id": ["Disk.Virtual.0:RAID.SL.3-1"],
                  "target": ["Disk.Bay.2:Enclosure.Internal.0-0:RAID.Integrated.1-1"]}
@@ -424,8 +429,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         with pytest.raises(Exception) as ex:
@@ -433,13 +438,13 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "Unable to locate the virtual disk with the ID: Disk.Virtual.0:RAID.SL.3-1"
 
     def test_online_capacity_expansion_empty_target(self, redfish_str_controller_conn, redfish_response_mock, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "OnlineCapacityExpansion",
                  "volume_id": ["Disk.Virtual.0:RAID.SL.3-1"],
                  "target": []}
         f_module = self.get_module_mock(params=param)
         mocker.patch(MODULE_PATH + "idrac_redfish_storage_controller.check_id_exists", return_value=None)
-        redfish_response_mock.json_data = {"Links": {"Drives": [{"@odata.id": "Drives/Disk.Bay.0:Enclosure.Internal.0-0:RAID.Integrated.1-1"}]}}
+        redfish_response_mock.json_data = {"Links": {"Drives": [{ODATA_ID: "Drives/Disk.Bay.0:Enclosure.Internal.0-0:RAID.Integrated.1-1"}]}}
         with pytest.raises(Exception) as ex:
             self.module.online_capacity_expansion(f_module, redfish_str_controller_conn)
         assert ex.value.args[0] == "Provided list of targets is empty."
@@ -451,7 +456,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "The Fully Qualified Device Descriptor (FQDD) of the target virtual drive must be only one."
 
     def test_online_capacity_expansion_valid_target(self, redfish_str_controller_conn, redfish_response_mock, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "OnlineCapacityExpansion",
                  "volume_id": "Disk.Virtual.0:RAID.SL.3-1",
                  "target": ["Disk.Bay.2:Enclosure.Internal.0-0:RAID.Integrated.1-1",
@@ -459,7 +464,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
                             "Disk.Bay.4:Enclosure.Internal.0-0:RAID.Integrated.1-1"]}
         f_module = self.get_module_mock(params=param)
         mocker.patch(MODULE_PATH + "idrac_redfish_storage_controller.check_id_exists", return_value=None)
-        redfish_response_mock.json_data = {"Links": {"Drives": [{"@odata.id": "/Drives/Disk.Bay.0:Enclosure.Internal.0-0:RAID.Integrated.1-1"}]},
+        redfish_response_mock.json_data = {"Links": {"Drives": [{ODATA_ID: "/Drives/Disk.Bay.0:Enclosure.Internal.0-0:RAID.Integrated.1-1"}]},
                                            "RAIDType": "RAID0"}
         redfish_response_mock.headers = {"Location": "/redfish/v1/Managers/iDRAC.Embedded.1/Jobs/JID_XXXXXXXXXXXXX"}
         f_module.check_mode = True
@@ -483,7 +488,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "No changes found to be applied."
 
     def test_online_capacity_expansion_size(self, redfish_str_controller_conn, redfish_response_mock, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "OnlineCapacityExpansion",
                  "volume_id": ["Disk.Virtual.0:RAID.SL.3-1"],
                  "size": 3010}
@@ -512,8 +517,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         resp = self.module.get_current_time(redfish_str_controller_conn)
@@ -521,8 +526,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert resp[1] is None
 
     def test_validate_time(self, redfish_str_controller_conn, redfish_response_mock, redfish_default_args):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "controller_id": "RAID.Integrated.1-1",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "controller_id": RAID_INTEGRATED_1_1,
                  "attributes": {"ControllerMode": "RAID", "CheckConsistencyMode": "Normal"},
                  "job_wait": True, "apply_time": "InMaintenanceWindowOnReset",
                  "maintenance_window": {"start_time": "2023-09-30T05:15:40-06:00", "duration": 900}}
@@ -547,8 +552,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
                                     " to schedule the maintenance window."
 
     def test_check_attr_exists(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "controller_id": "RAID.Integrated.1-1",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "controller_id": RAID_INTEGRATED_1_1,
                  "attributes": {"ControllerMode": "RAID", "CheckConsistencyMode": "Normal"},
                  "job_wait": True, "apply_time": "InMaintenanceWindowOnReset",
                  "maintenance_window": {"start_time": "2023-09-30T05:15:40-06:00", "duration": 900}}
@@ -574,14 +579,14 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "The following attributes are invalid: ['CheckConsistency']"
 
     def test_get_attributes(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "controller_id": "RAID.Integrated.1-1",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "controller_id": RAID_INTEGRATED_1_1,
                  "attributes": {"ControllerMode": "RAID", "CheckConsistencyMode": "Normal"},
                  "job_wait": True, "apply_time": "InMaintenanceWindowOnReset",
                  "maintenance_window": {"start_time": "2023-09-30T05:15:40-06:00", "duration": 900}}
         resp = {"@Redfish.Settings": {"SupportedApplyTimes": ["Immediate", "OnReset", "AtMaintenanceWindowStart",
                                                               "InMaintenanceWindowOnReset"]},
-                "Id": "RAID.Integrated.1-1",
+                "Id": RAID_INTEGRATED_1_1,
                 "Oem": {
                     "Dell": {
                         "DellStorageController": {
@@ -652,16 +657,16 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         resp = self.module.get_attributes(f_module, redfish_str_controller_conn)
         assert resp == {}
 
     def test_get_redfish_apply_time(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "controller_id": "RAID.Integrated.1-1",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "controller_id": RAID_INTEGRATED_1_1,
                  "attributes": {"ControllerMode": "RAID", "CheckConsistencyMode": "Normal"},
                  "job_wait": True, "apply_time": "InMaintenanceWindowOnReset",
                  "maintenance_window": {"start_time": "2023-09-30T05:15:40-06:00", "duration": 900}}
@@ -675,8 +680,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert result['MaintenanceWindowDurationInSeconds'] == 900
         assert result['MaintenanceWindowStartTime'] == '2023-09-30T05:15:40-06:00'
 
-        param1 = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                  "controller_id": "RAID.Integrated.1-1",
+        param1 = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                  "controller_id": RAID_INTEGRATED_1_1,
                   "attributes": {"ControllerMode": "RAID", "CheckConsistencyMode": "Normal"},
                   "job_wait": True, "apply_time": "InMaintenanceWindowOnReset",
                   "maintenance_window": {"start_time": "2023-09-30T05:15:40-06:00", "duration": 900}}
@@ -696,8 +701,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
             assert result["status_msg"] == "Apply time InMaintenanceWindowOnReset is not supported."
 
     def test_apply_attributes(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "controller_id": "RAID.Integrated.1-1",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "controller_id": RAID_INTEGRATED_1_1,
                  "attributes": {"ControllerMode": "RAID", "CheckConsistencyMode": "Normal"},
                  "job_wait": True, "apply_time": "Immediate"}
         time_settings = ["Immediate", "OnReset", "AtMaintenanceWindowStart", "InMaintenanceWindowOnReset"]
@@ -736,8 +741,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
 
         json_str = to_text(json.dumps({"data": "out"}))
         redfish_str_controller_conn.invoke_request.side_effect = HTTPError(
-            'http://testhost.com', 400,
-            'http error message',
+            HTTPS_ADDRESS, 400,
+            HTTP_ERROR_MSG,
             {"accept-type": "application/json"},
             StringIO(json_str))
         with pytest.raises(Exception) as ex:
@@ -746,12 +751,12 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         assert ex.value.args[0] == "Unable to configure the controller attribute(s) settings."
 
     def test_set_attributes(self, redfish_str_controller_conn, redfish_response_mock):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "controller_id": "RAID.Integrated.1-1", "attributes": {"ControllerMode": "HBA"},
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "controller_id": RAID_INTEGRATED_1_1, "attributes": {"ControllerMode": "HBA"},
                  "job_wait": True, "apply_time": "Immediate"}
         resp = {"@Redfish.Settings": {"SupportedApplyTimes": ["Immediate", "OnReset", "AtMaintenanceWindowStart",
                                                               "InMaintenanceWindowOnReset"]},
-                "Id": "RAID.Integrated.1-1",
+                "Id": RAID_INTEGRATED_1_1,
                 "Oem": {
                     "Dell": {
                         "DellStorageController": {
@@ -829,14 +834,136 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
             result = self.module.set_attributes(f_module, redfish_str_controller_conn)
             assert result['msg'] == "Other attributes cannot be updated when ControllerMode is provided as input."
 
+    def test_secure_erase(self, redfish_str_controller_conn, redfish_response_mock, redfish_default_args, mocker):
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password", "command": "SecureErase"}
+        module = 'idrac_redfish_storage_controller.'
+        redfish_default_args.update(param)
+        drive_id_1 = "Disk.Bay.0:Enclosure.Internal.0-1:RAID.Integrated.1-1"
+
+        def common_data_in_mock_dynamic_request(args):
+            odata = ODATA_ID
+            storage_uri = "/redfish/v1/Systems/System.Embedded.1/Storage"
+            drive_uri = storage_uri + "/RAID.Integrated.1-1/Drives/" + drive_id_1
+            if args[2] == "Storage":
+                return {odata: storage_uri}
+            elif args[2] == "Members":
+                return [{odata: storage_uri + "/RAID.Integrated.1-1"},
+                        {odata: storage_uri + "/AHCI.Embedded.2-1"}]
+            elif args[2] == "Drives":
+                return [{odata: storage_uri + drive_uri},
+                        {odata: storage_uri + "/RAID.Integrated.1-1/Drives/Disk.Bay.1:Enclosure.Internal.0-1:RAID.Integrated.1-1"}]
+            elif args[2] == "Actions":
+                return {"#Drive.SecureErase": {"target": drive_uri + "/Actions/Drive.SecureErase"}}
+
+        def mock_get_dynamic_uri_request_1(*args, **kwargs):
+            if len(args) > 2:
+                return common_data_in_mock_dynamic_request(args)
+            return {"Oem": {"Dell": {"DellPhysicalDisk": {"RaidStatus": "Online",
+                                                          "SystemEraseCapability": "NotSupported"}}}}
+
+        mocker.patch(MODULE_PATH + module + "get_dynamic_uri", side_effect=mock_get_dynamic_uri_request_1)
+        mocker.patch(MODULE_PATH + module + "validate_and_get_first_resource_id_uri",
+                     return_value=("/redfish/v1/Systems", None))
+
+        # Scenario 1: When command is set to SecureErase but controller_id and target is not provided
+        with pytest.raises(Exception) as ex:
+            self._run_module(redfish_default_args)
+        assert ex.value.args[0]["msg"] == "command is SecureErase but all of the following are missing: controller_id, target"
+
+        # Scenario 2: When command is set to SecureErase and only controller_id is provided
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1})
+        with pytest.raises(Exception) as ex:
+            self._run_module(redfish_default_args)
+        assert ex.value.args[0]["msg"] == "command is SecureErase but all of the following are missing: target"
+
+        # Scenario 3: When command is set to SecureErase and wrong controller_id is provided
+        redfish_default_args.update({"controller_id": "xyz",
+                                     "target": drive_id_1})
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Unable to locate the storage controller with the ID: xyz"
+
+        # Scenario 3A: When command is set to SecureErase and partial controller_id is provided
+        redfish_default_args.update({"controller_id": "RAID.Integrated",
+                                     "target": drive_id_1})
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Unable to locate the storage controller with the ID: RAID.Integrated"
+
+        # Scenario 4: When command is set to SecureErase and wrong target is provided
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1,
+                                     "target": "target"})
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Unable to locate the physical disk with the ID: target"
+
+        # Scenario 4A: When command is set to SecureErase and partial target is provided
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1,
+                                     "target": "Disk.Bay"})
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Unable to locate the physical disk with the ID: Disk.Bay"
+
+        # Scenario 5: When drive is not ready, in Online state
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1,
+                                     "target": drive_id_1})
+        mocker.patch(MODULE_PATH + module + "get_idrac_firmware_version", return_value='7.10')
+        mocker.patch(MODULE_PATH + module + "get_dynamic_uri",
+                     side_effect=mock_get_dynamic_uri_request_1)
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Drive {0} is not in ready state.".format(drive_id_1)
+
+        # Scneario 6: When drive is ready but not support secure erase
+        def mock_get_dynamic_uri_request_2(*args, **kwargs):
+            if len(args) > 2:
+                return common_data_in_mock_dynamic_request(args)
+            return {"Oem": {"Dell": {"DellPhysicalDisk": {"RaidStatus": "Ready",
+                                                          "SystemEraseCapability": "NotSupported"}}}}
+
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1,
+                                     "target": drive_id_1})
+        mocker.patch(MODULE_PATH + module + "get_dynamic_uri",
+                     side_effect=mock_get_dynamic_uri_request_2)
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Drive {0} does not support secure erase operation.".format(drive_id_1)
+
+        # Scenario 7: When drive is ready and support secure erase, job_wait is false
+        def mock_get_dynamic_uri_request_3(*args, **kwargs):
+            if len(args) > 2:
+                return common_data_in_mock_dynamic_request(args)
+            return {"Oem": {"Dell": {"DellPhysicalDisk": {"RaidStatus": "Ready",
+                                                          "SystemEraseCapability": "CryptographicErasePD"}}}}
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1,
+                                     "target": drive_id_1,
+                                     "job_wait": False})
+        mocker.patch(MODULE_PATH + module + "get_dynamic_uri",
+                     side_effect=mock_get_dynamic_uri_request_3)
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Successfully submitted the job that performs the 'SecureErase' operation."
+
+        # Scenario 8: When drive is ready and support secure erase, job_wait is true
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1,
+                                     "target": drive_id_1,
+                                     "job_wait": True,
+                                     "job_wait_timeout": 2})
+        obj = MagicMock()
+        obj.json_data = {'JobState': 'Completed'}
+        mocker.patch(MODULE_PATH + module + "wait_for_job_completion", return_value=(obj, ''))
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Successfully performed the 'SecureErase' operation."
+
+        # Scenario 9: When one Job is already running, and another trigger
+        redfish_default_args.update({"controller_id": RAID_INTEGRATED_1_1,
+                                     "target": drive_id_1})
+        mocker.patch(MODULE_PATH + module + "get_scheduled_job_resp", return_value={"Id": 'JOB_XXXX'})
+        result = self._run_module(redfish_default_args)
+        assert result["msg"] == "Unable to complete the operation because another job already exists." + \
+            " Wait for the pending job to complete and retry the operation."
+
     def test_main_success_attributes(self, redfish_str_controller_conn, redfish_response_mock, redfish_default_args, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "controller_id": None,
                  "attributes": {"ControllerMode": "RAID", "CheckConsistencyMode": "Normal"},
                  "job_wait": True, "apply_time": "Immediate"}
         resp = {"@Redfish.Settings": {"SupportedApplyTimes": ["Immediate", "OnReset", "AtMaintenanceWindowStart",
                                                               "InMaintenanceWindowOnReset"]},
-                "Id": "RAID.Integrated.1-1",
+                "Id": RAID_INTEGRATED_1_1,
                 "Oem": {
                     "Dell": {
                         "DellStorageController": {
@@ -904,7 +1031,7 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         mocker.patch(MODULE_PATH + 'idrac_redfish_storage_controller.check_id_exists', return_value=None)
         result = self._run_module(redfish_default_args)
         assert result['msg'] == "controller_id is required to perform this operation."
-        param.update({"controller_id": "RAID.Integrated.1-1"})
+        param.update({"controller_id": RAID_INTEGRATED_1_1})
         param.update({"job_wait": False})
         redfish_default_args.update(param)
         mocker.patch(MODULE_PATH + 'idrac_redfish_storage_controller.check_id_exists', return_value=None)
@@ -931,8 +1058,8 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
                                           ImportError, ValueError, TypeError, HTTPError])
     def test_main_error(self, redfish_str_controller_conn, redfish_response_mock, mocker,
                         exc_type, redfish_default_args):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
-                 "command": "ResetConfig", "controller_id": "RAID.Integrated.1-1"}
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
+                 "command": "ResetConfig", "controller_id": RAID_INTEGRATED_1_1}
         redfish_default_args.update(param)
         mocker.patch(MODULE_PATH + 'idrac_redfish_storage_controller.validate_inputs', return_value=None)
         redfish_response_mock.success = False
@@ -946,20 +1073,20 @@ class TestIdracRedfishStorageController(FakeAnsibleModule):
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'idrac_redfish_storage_controller.ctrl_reset_config',
                          side_effect=exc_type('exception message'))
-            result = self._run_module_with_fail_json(redfish_default_args)
+            result = self._run_module(redfish_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'idrac_redfish_storage_controller.ctrl_reset_config',
-                         side_effect=exc_type('http://testhost.com', 400, 'http error message',
+                         side_effect=exc_type(HTTPS_ADDRESS, 400, HTTP_ERROR_MSG,
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(redfish_default_args)
+            result = self._run_module(redfish_default_args)
             assert result['failed'] is True
         assert 'msg' in result
 
     def test_main_success(self, redfish_str_controller_conn, redfish_response_mock, redfish_default_args, mocker):
-        param = {"baseuri": "192.168.0.1", "username": "username", "password": "password",
+        param = {"baseuri": "XX.XX.XX.XX", "username": "username", "password": "password",
                  "command": "SetControllerKey", "key": "Key@123", "key_id": "keyid@123",
-                 "controller_id": "RAID.Integrated.1-1",
+                 "controller_id": RAID_INTEGRATED_1_1,
                  "target": ["Disk.Bay.0:Enclosure.Internal.0-1:RAID.Slot.1-1"]}
         redfish_default_args.update(param)
         mocker.patch(MODULE_PATH + 'idrac_redfish_storage_controller.validate_inputs', return_value=None)
